.. Copyright (C) 2024- Davide Mollica <davide.mollica@inaf.it>
.. SPDX-License-Identifier: GPL-3.0-or-later
..
.. This file is part of iactsim.
..
.. iactsim is free software: you can redistribute it and/or modify
.. it under the terms of the GNU General Public License as published by
.. the Free Software Foundation, either version 3 of the License, or
.. (at your option) any later version.
..
.. iactsim is distributed in the hope that it will be useful,
.. but WITHOUT ANY WARRANTY; without even the implied warranty of
.. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.. GNU General Public License for more details.
..
.. You should have received a copy of the GNU General Public License
.. along with iactsim.  If not, see <https://www.gnu.org/licenses/>.

iactsim documentation
=====================

Release |version|

Welcome to the documentation of **iactsim**.

`iactsim` is a CUDA-accelerated Imaging Atmospheric Cherenkov Telescopes (IACTs) Python simulation framework 
designed to accelerate computationally intensive tasks (like ray-tracing and pixels response) and provide 
a flexible and developer-friendly collection of tools for IACT performance studies. 
These tools are intended to facilitate and accelerate instrument design studies and data analysis.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   about
   reference/reference

